import { Module } from "@nestjs/common";
import { ConfigModule } from "@nestjs/config";
import { TypeOrmModule } from "@nestjs/typeorm";
import { AppController } from "./app.controller";
import { AppService } from "./app.service";
import { UsersRepository } from "./modules/users/user.repository";
import { UsersModule } from "./modules/users/users.module";
import { UsersService } from "./modules/users/users.service";
import { AuthModule } from "./modules/auth/auth.module";
import { JwtModule } from "@nestjs/jwt";
import { EmailNotifierModule } from "./modules/email-notifier/email-notifier.module";
import JwtConfigService from "./core/jwt/jwt-config.service";
import { MailerModule } from "@nestjs-modules/mailer";
import { HandlebarsAdapter } from "@nestjs-modules/mailer/dist/adapters/handlebars.adapter";
import { ServeStaticModule } from "@nestjs/serve-static";
import { join } from "path";
import { FileUploadsModule } from "./modules/file-uploads/file-uploads.module";
import { SendEmailModule } from "./modules/send-email/send-email.module";
import { SendEmailService } from "./modules/send-email/send-email.service";
import { SendEmailRepository } from "./modules/send-email/send-email-repository";
import { EmailNotifierRepository } from "./modules/email-notifier/email-notifier-repository";
import { FileUploadsService } from "./modules/file-uploads/file-uploads.service";
import { MailSenderModule } from "./modules/mail-sender/mail-sender.module";
import { SpacesModule } from "./modules/SpacesModule/spaces.module";
import { DoSpacesService } from "./modules/SpacesModule/SpacesService/doSpacesService";
import { DoSpacesServicerovider } from "./modules/SpacesModule/SpacesService";
import { LandingPageCmsModule } from "./modules/CMS/landing-page-cms/landing-page-cms.module";
import { CheckoutModule } from "./modules/dutchie-plus/checkout/checkout.module";
import { ProductModule } from "./modules/dutchie-plus/product/product.module";
import { RetailerModule } from "./modules/dutchie-plus/retailer/retailer.module";
import { SpecialsModule } from "./modules/dutchie-plus/specials/specials.module";
import { OrderModule } from "./modules/dutchie-plus/order/order.module";
import { CustomerModule } from "./modules/dutchie-plus/customer/customer.module";
import { SchedulerModule } from "./modules/scheduler/scheduler.module";
import { ProductCategoryModule } from "./modules/dutchie-plus/custom/product-category/product-category.module";
import { ProductServiceModule } from "./modules/dutchie-plus/custom/product-service/product-service.module";
import { OrderServiceModule } from "./modules/dutchie-plus/custom/order-service/order-service.module";
import { SigninPageCmsModule } from "./modules/CMS/signin-page-cms/signin-page-cms.module";
import { StoreCmsModule } from "./modules/CMS/store-cms/store-cms.module";
import { SignupPageCmsModule } from "./modules/CMS/signup-page-cms/signup-page-cms.module";
import { ChooseRetailerPageCmsModule } from "./modules/CMS/choose-retailer-page-cms/choose-retailer-page-cms.module";
import { CareerListPageCmsModule } from "./modules/CMS/career-list-page-cms/career-list-page-cms.module";
import { CareerDetailsPageCmsModule } from "./modules/CMS/career-details-page-cms/career-details-page-cms.module";
import { ApplyCareerModalCmsModule } from "./modules/CMS/apply-career-modal-cms/apply-career-modal-cms.module";
import {
    ScheduleVendorDayBannerCmsModule
} from "./modules/CMS/schedule-vendor-day-banner-cms/schedule-vendor-day-banner-cms.module";
import { FAQPageCmsModule } from "./modules/CMS/faq-page-cms/faq-page-cms.module";
import { TermsOfServiceCmsModule } from "./modules/CMS/terms-of-service-cms/terms-of-service-cms.module";
import { PrivacyPolicyCmsModule } from "./modules/CMS/privacy-policy-cms/privacy-policy-cms.module";
import { CareerApplicantModule } from "./modules/career-applicant/career-applicant.module";
import { CareerDepartmentModule } from "./modules/career-department/career-department.module";
import { CareerModule } from "./modules/career/career.module";
import { WhyJoinUsModule } from "./modules/why-join-us/why-join-us.module";
import { BlogCategoryModule } from "./modules/blog/blog-category/blog-category.module";
import { BlogTagModule } from "./modules/blog/blog-tag/blog-tag.module";
import { BlogPostModule } from "./modules/blog/blog-post/blog-post.module";
import { BlogPostTagsModule } from "./modules/blog/blog-post-tags/blog-post-tags.module";
import { FaqPageSectionTwoModule } from "./modules/faq-page-section-two/faq-page-section-two.module";
import { ContactUsSectionOneModule } from "./modules/contact-us-section-one/contact-us-section-one.module";
import { ContactUsPageCmsModule } from "./modules/CMS/contact-us-page-cms/contact-us-page-cms.module";
import { NewsletterBannerCmsModule } from "./modules/CMS/newsletter-banner-cms/newsletter-banner-cms.module";
import { SiteFrontendModule } from "./modules/site-frontend/site-frontend.module";
import { CkeditorFileModule } from "./modules/ckeditor-file/ckeditor-file.module";
import { FAQModule } from "./modules/faq/faq.module";
import { DispoDifferenceSectionModule } from "./modules/dispo-difference-section/dispo-difference-section.module";
import { AboutUsSectionTwoModule } from "./modules/about-us-section-two/about-us-section-two.module";
import { AboutUsPageCmsModule } from "./modules/CMS/about-us-page-cms/about-us-page-cms.module";
import { AboutUsSectionOneCmsModule } from "./modules/CMS/about-us-section-one-cms/about-us-section-one-cms.module";
import { CommonCmsModule } from "./modules/CMS/common-cms/common-cms.module";
import { RetailerServiceModule } from "./modules/dutchie-plus/custom/retailer-service/retailer-service.module";
import { ContactMessageModule } from "./modules/contact-message/contact-message.module";
import { NewsletterModule } from "./modules/newsletter/newsletter.module";
import { ReeferFriendCmsModule } from "./modules/CMS/reefer-friend-cms/reefer-friend-cms.module";
import { HeroSectionLeftCmsModule } from "./modules/CMS/hero-section-left-cms/hero-section-left-cms.module";
import { ReeferFriendModule } from "./modules/reefer-friend/reefer-friend.module";
import { HeroSectionSliderModule } from "./modules/hero-section-slider/hero-section-slider.module";
import { HomePageCmsModule } from "./modules/CMS/home-page-cms/home-page-cms.module";
import { HeaderCmsModule } from "./modules/CMS/header-cms/header-cms.module";
import { FooterCmsModule } from "./modules/CMS/footer-cms/footer-cms.module";
import { SiteSocialLinksModule } from "./modules/site-social-links/site-social-links.module";
import { ProductReviewModule } from "./modules/product-review/product-review.module";
import { InstagramImageModule } from "./modules/instagram-image/instagram-image.module";

@Module({
    imports: [
        ServeStaticModule.forRoot({
            rootPath: join(__dirname, "..", "uploads")
        }),
        ConfigModule.forRoot({ isGlobal: true }),
        TypeOrmModule.forRoot({
            type: "mysql",
            host: process.env.HOST,
            port: parseInt(process.env.PORT),
            username: process.env.USERNAME,
            // username: 'root',
            password: process.env.PASSWORD,
            database: process.env.DATABASE,
            autoLoadEntities: true,
            synchronize: true,
            dropSchema: false
        }),
        TypeOrmModule.forFeature([UsersRepository]),
        TypeOrmModule.forFeature([SendEmailRepository]),
        TypeOrmModule.forFeature([EmailNotifierRepository]),
        JwtModule.registerAsync({
            useClass: JwtConfigService
        }),
        MailerModule.forRoot({
            transport: {
                host: process.env.EMAIL_HOST,
                port: parseInt(process.env.EMAIL_PORT),
                secure: true,
                auth: {
                    user: process.env.EMAIL_USER,
                    pass: process.env.EMAIL_PASS
                }
            },
            defaults: {
                from: `"${process.env.EMAIL_SENDER_NAME}" <${process.env.EMAIL_SENDER_MAIL}>`
            },
            template: {
                dir: __dirname + "/templates/**/*",
                adapter: new HandlebarsAdapter(),
                options: {
                    strict: true
                }
            }
        }),
        UsersModule,
        AuthModule,
        EmailNotifierModule,
        FileUploadsModule,
        SendEmailModule,
        MailSenderModule,
        SpacesModule,
        LandingPageCmsModule,
        ProductModule,
        RetailerModule,
        SpecialsModule,
        CheckoutModule,
        OrderModule,
        CustomerModule,
        SchedulerModule,
        ProductCategoryModule,
        ProductServiceModule,
        OrderServiceModule,
        SigninPageCmsModule,
        StoreCmsModule,
        SignupPageCmsModule,
        ChooseRetailerPageCmsModule,
        CareerListPageCmsModule,
        CareerDetailsPageCmsModule,
        ApplyCareerModalCmsModule,
        ScheduleVendorDayBannerCmsModule,
        FAQPageCmsModule,
        TermsOfServiceCmsModule,
        PrivacyPolicyCmsModule,
        CareerApplicantModule,
        CareerDepartmentModule,
        CareerModule,
        WhyJoinUsModule,
        BlogCategoryModule,
        BlogTagModule,
        BlogPostModule,
        BlogPostTagsModule,
        FaqPageSectionTwoModule,
        ContactUsSectionOneModule,
        ContactUsPageCmsModule,
        NewsletterBannerCmsModule,
        SiteFrontendModule,
        CkeditorFileModule,
        FAQModule,
        DispoDifferenceSectionModule,
        AboutUsSectionTwoModule,
        AboutUsPageCmsModule,
        AboutUsSectionOneCmsModule,
        CommonCmsModule,
        RetailerServiceModule,
        ContactMessageModule,
        NewsletterModule,
        ReeferFriendCmsModule,
        HeroSectionLeftCmsModule,
        ReeferFriendModule,
        HeroSectionSliderModule,
        HomePageCmsModule,
        HeaderCmsModule,
        FooterCmsModule,
        SiteSocialLinksModule,
        ProductReviewModule,
        InstagramImageModule
    ],
    controllers: [AppController],
    providers: [
        AppService,
        UsersService,
        SendEmailService,
        FileUploadsService,
        DoSpacesService,
        DoSpacesServicerovider
    ]
})
export class AppModule {}
