import {HttpException, HttpStatus, Injectable} from "@nestjs/common";
import {InjectRepository} from "@nestjs/typeorm";
import {Constants} from "src/utils/constants";
import {ResponseUtils} from "src/utils/response.utils";
import {CareerListPageCmsRepository} from "./career-list-page-cms.repository";
import {UpdateCareerListPageCmsDto} from "./dto/update-career-list-page-cms.dto";
import {CareerListPageCmsEntity} from "./entities/career-list-page-cms.entity";
import {DoSpacesService} from "src/modules/SpacesModule/SpacesService/doSpacesService";
import {UploadedMulterFileI} from "src/modules/SpacesModule/SpacesService";

@Injectable()
export class CareerListPageCmsService {
    constructor(
        @InjectRepository(CareerListPageCmsRepository)
        private readonly repository: CareerListPageCmsRepository,
        private readonly doSpaceService: DoSpacesService
    ) {
    }

    async updateOrCreateData(
        dto: UpdateCareerListPageCmsDto,
    ): Promise<CareerListPageCmsEntity | Error> {
        const isExists = await this.repository.find({isDeleted: false});
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                    Constants.NOT_FOUND,
                    HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                    Constants.UPDATE_FAILED,
                    HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<CareerListPageCmsEntity[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(
                Constants.NOT_FOUND,
                HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}