import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { InjectRepository } from "@nestjs/typeorm";
import { Constants } from "src/utils/constants";
import { ResponseUtils } from "src/utils/response.utils";
import { CommonCmsRepository } from "./common-cms.repository";
import { UpdateCommonCmsDto } from "./dto/update-common-cms.dto";
import { CommonCmsEntity } from "./entities/common-cms.entity";
import { NewsletterBannerCmsRepository } from "../newsletter-banner-cms/newsletter-banner-cms.repository";
import { ReeferFriendCmsRepository } from "../reefer-friend-cms/reefer-friend-cms.repository";
import { ReeferFriendRepository } from "src/modules/reefer-friend/reefer-friend.repository";

@Injectable()
export class CommonCmsService {
    constructor(
        @InjectRepository(CommonCmsRepository)
        private readonly repository: CommonCmsRepository,
        @InjectRepository(NewsletterBannerCmsRepository)
        private readonly newsletterBannerCmsRepository: NewsletterBannerCmsRepository,
        @InjectRepository(ReeferFriendCmsRepository)
        private readonly reeferFriendCmsRepository: ReeferFriendCmsRepository,
        @InjectRepository(ReeferFriendRepository)
        private readonly reeferFriendRepository: ReeferFriendRepository
    ) { }

    async updateOrCreateData(
        dto: UpdateCommonCmsDto
    ): Promise<CommonCmsEntity | Error> {
        const isExists = await this.repository.find({ isDeleted: false });
        if (Object.keys(isExists).length === 0) {
            const data = await this.repository.createEntity(dto);
            if (!data) {
                throw new HttpException(
                    Constants.NOT_FOUND,
                    HttpStatus.NOT_FOUND
                );
            }
            return ResponseUtils.successResponseHandler(201, "Data created successfully!", "data", data);
        } else {
            let id = isExists[0].id;
            const data = await this.repository.updateEntity(dto, id);
            if (!data) {
                throw new HttpException(
                    Constants.UPDATE_FAILED,
                    HttpStatus.BAD_REQUEST
                );
            }
            return ResponseUtils.successResponseHandler(200, "Data updated successfully!", "data", data);
        }
    }

    async findAll(): Promise<CommonCmsEntity[] | Error> {
        const commonCmsData = await this.repository.findAll();
        const newsletterCmsData = await this.newsletterBannerCmsRepository.findAll();
        const reeferFriendCMS = await this.reeferFriendCmsRepository.findAll();
        const reeferFriend = await this.reeferFriendRepository.findByFilterQuery({});

        const data = {
            commonCMS: commonCmsData,
            newsletterCMS: newsletterCmsData,
            reeferFriendCMS: reeferFriendCMS,
            reeferFriend: reeferFriend
        };
        
        return ResponseUtils.successResponseHandler(200, "Data fetched successfully", "data", data);
    }
}