import { EntityRepository, getConnection, Repository } from "typeorm";
import { CreateCkeditorFileDto } from "./dto/create-ckeditor-file.dto";
import { UpdateCkeditorFileDto } from "./dto/update-ckeditor-file.dto";
import { CkeditorFile } from "./entities/ckeditor-file.entity";

@EntityRepository(CkeditorFile)
export class CkeditorFileRepository extends Repository<CkeditorFile> {

    async createEntity(dto: CreateCkeditorFileDto): Promise<CkeditorFile | Error> {
        try {
            const { upload, ckCsrfToken } = dto;
            const entity = this.create({
                fileName: dto.upload, 
                url: dto.upload
            });
            await this.save(entity);
            return entity;
        }
        catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<CkeditorFile[] | Error> {
        try {
            return await this.find({
                order: { createdAt: "DESC" },
                where: { ...query, isDeleted: false }
            });
        }
        catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<CkeditorFile | Error> {
        try {
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateCkeditorFileDto): Promise<CkeditorFile | Error> {
        try {
            await this.update(id, {
                fileName: dto.upload,
                url: dto.upload
            });
            return await this.findOne(id);
        }
        catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(CkeditorFile)
                .set({ isDeleted: true })
                .where("id = :id", { id: id })
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        }
        catch (e) {
            return e;
        }
    }

    async findByName(name: string): Promise<CkeditorFile[] | Error> {
        try {
            return await this.find({
                where: { 
                    name: name, 
                    isDeleted: false 
                }
            });
        }
        catch (e) {
            return e;
        }
    }

    async deleteImage(images : any): Promise<any | Error> {
        try {
            await getConnection()
                .createQueryBuilder()
                .delete()
                .from(CkeditorFile)
                .where("image IN (:image)", { image: images })
                .execute();
        }
        catch (e) {
            return e;
        }
    }

    async deleteImageByProductId(id : any): Promise<any | Error> {
        try {
            const deleteResult = await getConnection()
            .createQueryBuilder()
            .delete()
            .from(CkeditorFile)
            .where("productId = :productId", { productId : id })
            .execute();
        if(deleteResult.affected > 0) {
            return true;
        }
        return false;
        }
        catch (e) {
            return e;
        }
    }
}