import {EntityRepository, getConnection, Repository} from "typeorm";
import { InstagramImageEntity } from "./entities/instagram-image.entity";
import { CreateInstagramImageDto } from "./dto/create-instagram-image.dto";
import { UpdateInstagramImageDto } from "./dto/update-instagram-image.dto";

@EntityRepository(InstagramImageEntity)
export class InstagramImageRepository extends Repository<InstagramImageEntity> {
    async createEntity(dto: CreateInstagramImageDto): Promise<InstagramImageEntity | Error> {
        try {
            const {
                image
            } = dto;
            const entity = this.create({
                image
            });
            await this.save(entity);
            return entity;
        } catch (e) {
            return e;
        }
    }

    async findOneEntity(id: string): Promise<InstagramImageEntity | Error> {
        try {
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }

    async findByFilterQuery(query: any): Promise<InstagramImageEntity[] | Error> {
        try {
            return await this.find({
                where: {
                    ...query,
                    isDeleted: false
                },
                order: {
                    createdAt: "DESC"
                }
            });
        } catch (e) {
            return e;
        }
    }

    async deleteEntity(id: string): Promise<boolean | Error> {
        try {
            const updateResult = await getConnection()
                .createQueryBuilder()
                .update(InstagramImageEntity)
                .set({isDeleted: true})
                .where("id = :id", {id: id})
                .execute();
            if (updateResult.affected > 0) {
                return true;
            }
            return false;
        } catch (e) {
            return e;
        }
    }

    async countAllQuery(): Promise<any | Error> {
        try {
            return await this.count({
                where: {
                    isDeleted: false
                }
            });
        } catch (e) {
            return e;
        }
    }

    async updateEntity(id: string, dto: UpdateInstagramImageDto): Promise<InstagramImageEntity | Error> {
        try {
            await this.update(id, {
                image: dto.image
            });
            return await this.findOne(id);
        } catch (e) {
            return e;
        }
    }
}