import { Body, Controller, Delete, Get, Param, Patch, Post, UseGuards } from "@nestjs/common";
import { Constants } from "src/utils/constants";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { ReeferFriendService } from "./reefer-friend.service";
import { CreateReeferFriendDto } from "./dto/create-reefer-friend.dto";
import { UpdateReeferFriendDto } from "./dto/update-reefer-friend.dto";

@Controller({ path: "reefer-friend", version: Constants.API_VERSION_1 })

export class ReeferFriendController {
  constructor(private readonly service: ReeferFriendService) {
  }

  @Post()
  @UseGuards(AdminAuthGuard)
  create(
    @Body() dto: CreateReeferFriendDto
  ) {
    return this.service.create(dto);
  }

  @Get()
  @UseGuards(AdminAuthGuard)
  findAll() {
    return this.service.findAll();
  }

  @Get(":id")
  @UseGuards(AdminAuthGuard)
  findOne(@Param("id") id: string) {
    return this.service.findOne(id);
  }

  @Patch("/:id")
  @UseGuards(AdminAuthGuard)
  update(
    @Param("id") id: string,
    @Body() dto: UpdateReeferFriendDto) {
    return this.service.update(id, dto);
  }

  @Delete(":id")
  @UseGuards(AdminAuthGuard)
  async remove(@Param("id") id: string) {
    return await this.service.remove(id);
  }
}
